OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Доступна версия {version}. Получить дополнительную информацию о порядке обновления.",
    "Updater" : "Обновление",
    "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "По соображениям безопасности встроенное средство обновления ownCloud использует дополнительные учетные данные. Для перехода к странице обновления, пожалуйста, нажмите следующую кнопку.",
    "Open updater" : "Открыть окно обновления",
    "A new version is available: %s" : "Доступна новая версия: %s",
    "Checked on %s" : "Проверено %s",
    "Updated channel" : "Обновленный канал"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
